%% EasySpin Academy 2020 - Session 1 - Introduction
%===============================================================================
% (based on version 6.0.0-dev.26, possible changes for 6.0.0 final release)

%>> Welcome:
%>> - personal introduction
%>> - Stephan P behind scenes
%>> - first online ESA; large audience
%>> - cover basics of EasySpin, no particular depth in any topic
%>> - assumes familiarity with MATLAB
%>> - day 1: basics, day 2: fitting etc, day 3: more topics
%>> - flexible topics on 3rd day

%>> Organizational:
%>> - all links on the academy website [show]
%>> - 30min sessions with 10min buffer/break
%>> - demos + exercises in each session
%>> - everything is in script files, will provide exercise keys
%>> - questions on Slido; event code ESA2020 [show]
%>> - experts: please help out
%>> - main questions: we'll answer in Q&A at end of day
%>> - Happy Hour on gather.town; (not accessible now)
%>> - T-shirts: bonfire

%{
This session gives an introductory overview EasySpin.
%}

%% DEMONSTRATION 01-00: EasySpin Academy script files, MATLAB
%>> Described in the email
%>> - Download zip file
%>> - Unzip to a folder
%>> - Make that folder the current folder in MATLAB

%>> Show basics of MATLAB desktop
%>> - panel layout
%>> - command window, editor

%% DEMONSTRATION 01-01: EasySpin versions and installation
% Versions
% - 5.2.x: stable, but a little old by now
% - 6.0.0-dev.x: dev version, better; not complete yet, new features, more
%   changes wil come
% - 5.2 requires R2007b; 6.0 required R2016b
% - ESA uses 6.0.0-dev.26

% Installation
% - Download from website easyspin.org
% - Unzip downloaded file somewhere
% - Show EasySpin folder structure

% - Add easyspin-6.0.0-dev.26/easyspin to MATLAB path; save
% - Check EasySpin access and version in MATLAB with easyspin()
easyspin

%% EXERCISE 01-01: MATLAB path, EasySpin installation
%{
(1) Go to the ribbon menu HOME > ENVIRONMENT, and look at the MATLAB path.
Where is your EasySpin installation located? Do you have more than one?
(2) Type 'easyspin' in the command window to determine your EasySpin version.
%}
easyspin

%% DEMONSTRATION 01-02: EasySpin resources
%{
Resources:
- EasySpin online and local documentation
- EasySpin online and local examples
- EasySpin forum
%}

%% EXERCISE 01-02: EasySpin help
%{
Find help for EasySpin function sop() (spin operators) in different ways:
1) Go to docs/index.html -> Functions alphabetically.
2) Go to online docs at easyspin.org. (This is for version 5.2.x)
3) Type 'help sop' or just 'sop' in the Command Window.
%}

%% DEMONSTRATION 01-03: Data import and plotting

% function: eprload()

% Use clear to clear all variables
% Use clc to clear the command window
clear, clc

% cd into ESA2020 folder

% Load Bruker E500 data (DSC/DTA files) into variables and plot
[B,spc] = eprload('radical.DTA');
plot(B,spc);

% Load Bruker EMX (par/spc files) 
[B,spc] = eprload('DPPH.spc');
plot(B,spc);

% Third output of eprload(): parameters
[B,spc,par] = eprload('DPPH.spc');
par

% Alternative: file selection dialog
eprload

% Import data from text file
[B,spc] = textread('radical.txt','%f %f','headerlines',0);
plot(B,spc)

% other functions:
% - readtable() for Excel spreadsheet
% - load() for MAT files

% see section in documentation

%% EXERCISE 01-03: Data import and plotting
%{
Load the spectra stored in FeS_1.DTA and FeS_1.DSC and plot them.
%}
clf
[B1,spc1] = eprload('FeS_1.DTA');
[B2,spc2] = eprload('FeS_2.DTA');
plot(B1,spc1,B2,spc2);

%% DEMONSTRATION 01-04: Data export

clear, clc

% Generate some synthetic data
x = linspace(0,30,201);
y = exp(-(x-15).^2/2^2) + 0.2*rand(1,201);
plot(x,y);

% Use clf to clear a figure
% Use close to close figures

% eprsave(): export data in Bruker format
eprsave('mydata',x,y,'data title');

% save -ASCII: export data in text format
data = [x(:) y(:)];
save('mydata.txt','data','-ASCII');

% other functions:
% - writetable() for Excel spreadsheet
xlswrite('mydata',[x(:) y(:)])
writetable(table(x(:),y(:)),'mydata.xlsx')

%% EXERCISE 01-04: Data export
%{
(a) Generate a linear range from 300 to 400 with 1000 points (using linspace),
and an equally long vector of random numbers between 0 and 0.1 (using rand).
(b) Save the two vectors as x and y data in a Bruker DTA/DSC file (using eprsave).
(c) Save the data as two columns in a text file.
%}
B = linspace(300,400,1000);
spc = rand(1,1000)*0.1;
eprsave('myfile',B,spc,'My random data');

data = [B(:) spc(:)];
save('myfile.txt','data','-ASCII');


%% DEMONSTRATION 01-05: Plotting

figure; % open a new figure window

x = 1:50;
y = rand(1,50);

plot(x,y);
plot(x,y,'r');
plot(x,y,'o');

y2 = rand(1,50)-1;
hold on  % to add to the existing plot
plot(x,y2)

% labeling, etc
xlabel('magnetic field');
ylabel('data');
legend('run 1','run 2');
title('this is the title');
grid on
box on
axis tight
ylim([-2 2]);   % set y limits

% Show MATLAB help on plotting

%% EXERCISE 01-05: Plotting
%{
Take the data from before and plot them as red circles in a new figure. Label
the x and y axes, add a title, and switch the grid on. Set the x limits to
a range larger than the data range.
%}
clf
x = 1:50;
y = rand(1,50);
plot(x,y,'ro-');
xlabel('x axis');
ylabel('y axis');
title('my title');
grid on
xlim([-10 70]);

%% DEMONSTRATION 01-06: Figure export

% Copy to clipboard
% - Use figure menu: FIGURE > Edit > Copy figure
% You can then insert it into a powerpoint slidedeck or Word file etc.

% Export figure as pdf or png
% - Use figure menu: FIGURE > File > Save as...
% - Use print()
print -dpng -r600 myfigure
print -dpdf myfigure

% Set size
set(gcf,'PaperPosition',[0 0 8 5])
gcf().PaperUnits

%% EXERCISE 01-06: Figure export
%{
Plot the previous data again, and export the figure to (1) a png file, (2)
a pdf file, (3) into a Word file, (4) into a PowerPoint file.
%}
