%% EasySpin Academy 2020 - Session 2 - Spin systems
%===============================================================================
% (based on version 6.0.0-dev.26, possible changes for 6.0.0 final release)

%{
This session shows how spin centers are specified in EasySpin. All needed
parameters about the spin center are collected in a MATLAB structure.
%}

%% DEMONSTRATION 02-01: Electron spin
Sys.S = 1;
Sys.S = 5/2;
Sys.S = [1/2 1/2]; % two spins-1/2

%% EXERCISE 02-01: Electron spin
%{
Define a spin system with 2 spin-1/2 and one spin-1 (triplet).
%}
Sys.S = [1/2 1/2 1]

%% DEMONSTRATION 02-02: g tensors
clear, clc
Sys.g = [2.03 2.04 2.2]     % full tensor, rhombic here
Sys.g = [2.03 2.2]          % axial,  = [2.03 2.03 2.2]
Sys.g = 2.003;              % isotropic, = [2.003 2.003 2.003]

% Multiple electrons: one set of g values per row
Sys.g = [2.0 2.1 2.2; 1.93 1.93 1.99];

% Full tensor
Sys.g = diag([2.03 2.04 2.2]) % 3x3 matrix

%% EXERCISE 02-02: g tensors
%{
Define a spin system with two electron spins 1/2 and two g tensors: one with
isotropic g value 1.98, and one with anistropic values 1.8, 1.93, and 2.03.
%}
Sys.S = [1/2 1/2];
Sys.g = [1.98 1.98 1.98; 1.8 1.93 2.03];

%% DEMONSTRATION 02-03: Zero-field splitting

% Show help on spin Hamiltonian terms and parameters in EasySpin doc

clear
Sys.S = 1;   % triplet

Sys.D = 2870;             % D only; axial, MHz (NV- center in diamond)
Sys.D = [1300 260];       % [D E]; rhombic, MHz
Sys.D = 1300*[1 0.2];     % D*[1 E/D]; rhombic, MHz
Sys.D = [400 200 -600];   % ZFS tensor principal values, [Dx Dy Dz]

% full tensor also possible

%% EXERCISE 02-03: Zero-field splitting
%{
Given Dx = -100 MHz, Dy = -700 MHz, and Dz = +800 MHz, calculate D and E (see
doc on the zero-field splitting term in the spin Hamiltonian). Then, use D and E
to set Sys.D.
%}
clear
Dx = -100; % MHz
Dy = -700; % MHz
Dz = 800;  % MHz

D = 3/2*Dz
E = (Dx-Dy)/2

Sys.D = [D E]

%% DEMONSTRATION 02-04: Electron-electron couplings
Sys.S = [1/2 1/2];

% Exchange coupling
Sys.J = 100; % MHz
% corresponds to principal values [1 1 1]*100

% Dipolar coupling
Sys.dip = 5; % MHz
% corresponds to principal values [1 1 -2]*5

% General coupling tensor (= sum of exchange and dipolar coupling tensors)
% provide either diagonal or full matrix
Sys.ee = [20 30 50]; % MHz

%% EXERCISE 02-04: Electron-electron couplings
%{
Take a two-electron-spin system with exchange coupling of 5 MHz and dipolar
coupling of 15 MHz. (a) Set up the spin system structure. (b) Calculate the
principal values of the overall coupling tensor.
%}
clear
Sys.S = [1/2 1/2];
Sys.J = 5;
Sys.dip = 15;
ee = Sys.J*[1 1 1] + Sys.dip*[1 1 -2]

%% DEMONSTRATION 02-05: Nuclear spins
% isotopes() to see table
isotopes

% isotopologues() to analyze isotope compositions
clc
isotopologues('Cl,Cl')

% Sys.Nucs for isotopes and natural-abundance isotope mixtures
Sys.Nucs = '14N';
Sys.Nucs = 'N';
Sys.Nucs = '14N,1H,1H';
Sys.Nucs = 'Cu';

isotopologues(Sys)

% non-natural isotope mixtures are possible as well, see help

%% EXERCISE 02-05: Nuclear spins
%{
(a) Define a spin system with one electron spin 1/2 and a 55Mn nucleus.
(b) Define a spin system with electron spin 1 (a triplet) and 3 different 1H spins.
(c) Define a spin system with electron spin 3/2 and a natural-abundance chromium
nucleus.
%}
clear
Sys.S = 1/2;
Sys.Nucs = '55Mn';

Sys.S = 1;
Sys.Nucs = '1H,1H,1H';

Sys.S = 3/2;
Sys.Nucs = 'Cr';
isotopologues(Sys)

%% DEMONSTRATION 02-06: Hyperfine coupling
clear
Sys.Nucs = '1H';
Sys.A = [20 30 100];   % rhombic; MHz
Sys.A = [25 100];      % axial, equal to [25 25 100]
Sys.A = 50;            % isotropic; MHz

% also possible to specify full A tensors

% multiple nuclei: one set of A principal values per row
Sys.Nucs = '63Cu,14N';
Sys.A = [20 30 400; -8 -5 20]; 


%% EXERCISE 02-06: Hyperfine coupling
%{
Define a spin system with one electron spin 1/2  with g=1.998 and a 31P nucleus
with an anistropic hyperfine coupling with principal values 5.1, 6.6, and 8.3 MHz.
%}
clear
Sys.S = 1/2;
Sys.g = 1.998;
Sys.Nucs = '31P';
Sys.A = [5.1 6.6 8.3];

%% DEMONSTRATION 02-07: Nuclear quadrupole coupling
clear
Sys.Q = 0.7            % one nucleus, eeQq/h = 0.7 MHz
Sys.Q = [0.7, 1.2]     % same for two nuclei
Sys.Q = [1.2 0.29]         % one nucleus, eeQq/h = 1.2 MHz and eta = 0.29
Sys.Q = [1.2 0.29; 0.1 0]  % same with a second nucleus (second row)

% also possible to specify Q principal values, or full Q tensors

%% EXERCISE 02-07
%{
Define a spin system with a 14N nucleus and nuclear quadruple coupling of
eeqQ/h = -1.2 MHz and eta=0.2
%}

clear, clc
eeQqh = -1.2; % MHz
eta = 0.2;
Sys.Nucs = '14N';
Sys.Q = [eeQqh eta]
