%% EasySpin Academy 2020 - Session 5 - Coordinate frames etc.
%===============================================================================
% (based on version 6.0.0-dev.26, possible changes for 6.0.0 final release)
%{
In this session, we look at how coordiante frames are handled in EasySpin.

Most of EPR is on solid, therefore orientations play an important role. How
is the sample oriented in the spectrometer, how is the spin center oriented
within the sample - particularly if it's a crystal. And how are the various
tensors oriented within the spin center.
%}

%% DEMONSTRATION 05-01: Euler angles

% Two frames are related via Euler angles
% We've already seen Euler angles for tilted tensors: AFrame etc.

% Show Euler angle documentation

% erot() to get rotation matrix from Euler angles
alpha = deg2rad(20);
beta = deg2rad(40);
gamma = deg2rad(80);
R = erot(alpha,beta,gamma);

% Elements of rotation matrix are cosines of angles between pair of axes
acos(R)*180/pi
% The (3,3) element gives beta, the angle between the two z axes

% How to transform a tensor from one frame to the other
g_diag = diag([2.0 2.05 2.2])
R*g_diag*R'
% notion of transformation (passive) vs. actual rotation (active)

% eulang() to convert a rotation matrix to Euler angles
eulang(R)*180/pi

% rotview() to visualize the rotation and the Euler angles
% NEW IN VERSION 6
rotview

%% EXERCISE 05-01: Euler angles
%{
Take two frames related by the rotation matrix R = [0 1 0; 0 0 1; 1 0
0]. (A) Which axis from the first frame aligns with which axis of the
second frame? (B) Calculate the Euler angles associated with R.
%}

R = [0 1 0; 0 0 1; 1 0 0];
angles = acos(R)*180/pi
% -> x2 with y1, y2 with z1, z2 with x1
eulang(R)*180/pi

%% DEMONSTRATION 05-02: Tensor frames
% Molecular frame: a specific frame fixed with respect to the spin center
% If tensors are not aligned with the molecular frame: give Euler angles
% Show Euler angles help ("Rotations and Euler angles", "Coordinate frames")
clear

Sys.g = [2 2.05 2.2];

% A=50 MHz is along z axis
Sys.A = [10 10 50];
Sys.AFrame = [0 pi/2 0];

%% EXERCISE 05-02: Tensor frames
%{
a) Go to the doc on "Coordinate frames" and figure out whether the Euler angles
transform the molecular frame into the A frame, or vice versa.
b) Locate the doc on "Rotations and Euler angles" and identify the blue and
green frames with the A frame and the molecular frame.
c) How is the g frame in the above demonstation oriented relative to the
molecular frame?
%}

%% DEMONSTRATION 05-03: Dipolar coupling tensor

% diptensor() calculates full dipolar tensor
% NEW IN VERSION 6
r = [0;0;1];  % inter-spin vector, nm
diptensor('e','e',r)

% Change to e-1H and 1H-1H

% use angles to define direction
r = 1*ang2vec(pi/4,pi/4)
T = diptensor('e','e',r)
[R,Tev] = eig(T)
R= R(:,[1 3 2])
eulang(R)

%% EXERCISE 05-03: Dipolar coupling tensor
%{
An electron spin is delocalized over two atoms: 70% on atom 1 at [0 0 0],
and 30% on atom 2 at [0 0 0.2] (in nanometers). Calculate the dipolar
hyperfine coupling tensor of a proton at [0.3 -0.2 0.1] to this delocalized
electron. Determine its eigenvalues.
%}

re1 = [0 0 0];   % atom 1
re2 = [0 0 0.2]; % atom 2
rH = [0.3 -0.2 0.1] % proton

Adip1 = 0.7*diptensor('e','1H',rH-re1)
Adip2 = 0.3*diptensor('e','1H',rH-re2)
Adip = Adip1+Adip2

eig(Adip)

%% DEMONSTRATION 05-04: Orientations, vectors and angles
% Construct unit vector from spherical coordinates
phi = deg2rad(10); % degrees->radians (deg2rad works in R2015b or later)
theta = deg2rad(45); % degrees->radians
zL = ang2vec(phi,theta)
norm(zL)

% magnetic field in molecular frame
B = 350*zL % mT
norm(B)

% Get angles from vector
zL = 2*rand(3,1)-1; % generate random vector
zL = zL/norm(zL); % normalize
[phi,theta] = vec2ang(zL)

rad2deg(phi)   % rad2deg works in R2015b or later)
rad2deg(theta)

%% EXERCISE 05-04: Orientations, vectors and angles
%{
Calculate the angles phi and theta (in degrees) for the vector [1;1;1], i.e. a
vector that connects two vertices of a cube across the space diagonal of the cube.
%}
v = [1;1;1];
[phi,theta] = vec2ang(v);
rad2deg(phi)
rad2deg(theta)

% This theta value is called the "magic angle".

%% DEMONSTRATION 05-05: Frame rotations
% Active rotations happen in crystal studies. EasySpin provides
% rotateframe() to perform rotations.

clear, clc
ori0 = [40 65 0]*pi/180; % initial frame orientation

xL = [1;0;0];  % laboratory-fixed x axis ( = sample axis in X-band)
rho = 20*pi/180; % rotation angle (radians)

ori = rotateframe(ori0,xL,rho)

R = erot(ori)

%% EXERCISE 05-05: Frame rotations
%{
Take a frame with orientation [0 0 0] (Euler angles) and rotate it by
120 degrees around the [1 1 1] axis. Give the final Euler angles and 
rotation matrix. Visualize the rotated frame with rotview().
%}

clear, clc
n = [1;1;1]; % rotation axis, does not have to be unit vector
rho = 120*pi/180;
ori0 = [0 0 0];
ori = rotateframe(ori0,n,rho)
R = erot(ori)
