%% EasySpin Academy 2020 - Session 6 - Solid-state EPR II
%===============================================================================
% (based on version 6.0.0-dev.26, possible changes for 6.0.0 final release)
%{
This session continues to describe how to simulate solid-state EPR spectra,
using EasySpin's function pepper.
%}

%% DEMONSTRATION 06-01: High-spin system
clear, clc
Sys.S = 1;
Sys.D = [1000 130]; % MHz
Sys.lwpp = 2; % mT
Exp.mwFreq = 10; % GHz
Exp.Range = [300 420]; % mT
pepper(Sys,Exp);

% Extend range to see half-field (double-quantum) transition
Exp.Range = [150 420]; % mT
pepper(Sys,Exp);

%% EXERCISE 06-01: High-spin systems
%{
Simulate the W-band EPR absorption spectrum of a Gd(III) compound. Parameters:
S=7/2, D = -1500 MHz, E/D = 0.2, D strain 400 MHz, E strain 150 MHz. Also, look
at the spectra of the individual transitions.
%}
clear
Gd.S = 7/2;
Gd.D = -1500*[1 0.2]; % MHz
Gd.DStrain = [300 150]; % MHz
Exp.mwFreq = 95; % GHz
Exp.Range = [2800 4000]; % mT
Exp.Harmonic = 0;
Opt.Output = 'summed';
pepper(Gd,Exp,Opt);

Opt.Output = 'separate';
pepper(Gd,Exp,Opt);


%% DEMONSTRATION 06-02: Temperature
% going back to the system of the previous demonstration
clear
Sys.S = 1;
Sys.D = [1000 130]; % MHz
Sys.lwpp = 1; % mT
Exp.mwFreq = 10; % GHz
Exp.Range = [300 420]; % mT

Exp.Temperature = 2; % K
pepper(Sys,Exp);

% show as absorption spectrum

% show with inverted sign of D

%% EXERCISE 06-02: Temperature
%{
Take the Gd system from before and simulate its W-band absorption spectrum at a
temperature of 4 K. Then simulate it again inverting the signs of D and E. Plot
the two spectra in the same figure.
%}
clear
Gd.S = 7/2;
Gd.D = -1500*[1 0.2]; % MHz
Gd.DStrain = [300 150]; % MHz
Exp.mwFreq = 95; % GHz
Exp.Range = [2800 4000]; % mT
Exp.Harmonic = 0;
Exp.Temperature = 4; % K

Opt.Output = 'summed';
[B,spcm] = pepper(Gd,Exp,Opt);
Gd.D = -Gd.D;
[B,spcp] = pepper(Gd,Exp,Opt);

plot(B,spcm,B,spcp);
legend('D > 0','D < 0');
xlabel('magnetic field (mT)');

%% DEMONSTRATION 06-03: Multiple components
clear
Sys1.g = [1.95 1.98 2.05];
Sys1.lwpp = 1; % mT
Sys2.g = [1.91 2.0 2.17];
Sys2.lwpp = 2; % mT

Sys1.weight = 0.3;
Sys2.weight = 0.7;

Exp.mwFreq = 9.5; % GHz
Exp.Range = [300 400]; % mT

pepper({Sys1,Sys2},Exp);

%% EXERCISE 06-03: Multiple components
%{
Simulate a solid-state spectrum containing 99% of a Fe-S cluster with S = 1/2,
g = [1.8 1.95 2.05] and lwpp = 5 mT, and 1% of a free radical with g = 2.003
and lwpp = 1 mT. Use 9.8 GHz.
%}
clear, clc
FeS.S = 1/2;
FeS.g = [1.8 1.95 2.05];
FeS.lwpp = 5;
R.S = 1/2;
R.g = 2.003;
R.lwpp = 1;

FeS.weight = 0.99;
R.weight = 0.01;

Exp.mwFreq = 9.8;
Exp.Range = [320 420];
pepper({FeS,R},Exp);

%% DEMONSTRATION 06-04: Crystals
clear, clc
Sys.g = [2 2.1 2.2];
Sys.lwpp = 0.5; % mT

Exp.MolFrame = [0 pi/8 0]; % tilt molecule relative to crystal ref. frame

Exp.mwFreq = 9.5; % GHz
Exp.Range = [300 350]; % mT

% powder spectrum
[B,spc0] = pepper(Sys,Exp);

% crystal spectrum
Exp.CrystalOrientation = [30 20 40]*pi/180; % radians
[B,spc1] = pepper(Sys,Exp);

subplot(2,1,1)
plot(B,spc0);
subplot(2,1,2)
plot(B,spc1);

% add and change space group (Exp.CrystalSymmetry = 1, 50, 100, 227)
Exp.CrystalSymmetry = 227;
[B,spc1] = pepper(Sys,Exp);
plot(B,spc1);

% Specify orientation of molecule in crystal: Exp.MolFrame
% Specify orientation of crystal in spectrometer: Exp.CrystalOrientation

% To rotate sample: Exp.SampleRotation
xL = [1;0;0];   % x-axis in lab = sample axis in X-band spectrometer
rho = 10*pi/180; % rotation angle
Exp.SampleRotation = {rho,xL};
[B,spc1] = pepper(Sys,Exp);
plot(B,spc1);

% change rho by 1-degree increments

%% EXERCISE 06-04: Crystals
%{
Simulate an 9.5 GHz powder spectrum of Cu(II) with g = [2.05 2.09 2.2] and A(63Cu) =
[50 350] MHz, lwpp 1 mT, field range [280 350] mT. Then simulate crystal spectra
of the same system with the magnetic field aligned along the molecular x axis and
along the molecular z axis. Plot all spectra in the same figure, powder spectrum
on top, and crystal spectra on bottom.
%}
clear, clc
Cu.S = 1/2;
Cu.g = [2.05 2.09 2.2];
Cu.Nucs = '63Cu';
Cu.A = [50 350]; % MHz
Cu.lwpp = 1; % mT

Exp.mwFreq = 9.5; % GHz
Exp.Range = [280 350]; % mT

[B,spc] = pepper(Cu,Exp);

Exp.CrystalOrientation = [0 0 0]; % radians
[B,spcz] = pepper(Cu,Exp);
Exp.CrystalOrientation = [0 pi/2 0]; % radians
[B,spcx] = pepper(Cu,Exp);
Exp.CrystalOrientation = [pi/2 pi/2 0]; % radians
[B,spcy] = pepper(Cu,Exp);

subplot(2,1,1);
plot(B,spc);
subplot(2,1,2);
plot(B,spcx,B,spcy,B,spcz);

%% DEMONSTRATION 06-05: Parallel mode
clear, clc
Sys.S = 2; % this could be e.g. Fe(II)
Sys.D = 300e3*[1 0.1]; % MHz
Sys.lwpp = 10; % mT
Exp.mwFreq = 9.5; % GHz
Exp.Range = [0 600]; % mT
Opt.nKnots = 31;

Exp.Mode = 'perpendicular'; % default
[B,spc_perp] = pepper(Sys,Exp,Opt);
Exp.Mode = 'parallel';
[B,spc_para] = pepper(Sys,Exp,Opt);

plot(B,spc_perp,B,spc_para);

legend('perpendicular','parallel');

%% EXERCISE 06-06: Parallel mode
%{
Simulate the parallel- and the perpendicular-mode X-band EPR spectrum of a
triplet with D = 2 GHz. Repeat with D = 8 GHz.
%}
clear, clc
T.S = 1;
T.D = 2e3; % MHz
T.lwpp = 4;
Exp.mwFreq = 9.5;
Exp.Range = [0 600];

Exp.Mode = 'perpendicular';
[B1,spc1] = pepper(T,Exp);
Exp.Mode = 'parallel';
[B2,spc2] = pepper(T,Exp);
plot(B1,spc1,B2,spc2);
legend('perpendicular','parallel');

%% DEMONSTRATION 06-07: Spin-polarized triplets
clear

Sys.S = 1;
Sys.g = 2.00;
Sys.D = [342 21]; % MHz (values for excited triplet state of C60)

% The three numbers in Sys.Pop give the relative
% populations of the three sublevels at zero-field (where
% T0 is lowest in energy) in order of increasing energy.
Sys.Pop = [1 0 0];

Sys.lwpp = 0.2;   % mT

Exp.mwFreq = 9.248;  % GHz
Exp.Range = [310 350];      % mT

% Transient EPR: no field modulation!
Exp.Harmonic = 0;

pepper(Sys,Exp);

% This applies to ISC triplets, i.e. triplet obtained through inter-system
% conversion from a singlet.

% show separate transitions
Opt.Output = 'separate';
pepper(Sys,Exp,Opt);

%% EXERCISE 06-07
%{
Simulate the spin-polarized X-band EPR spectrum of a triplet with x/y/z
populations 1, 0, and 1. Use D = 1 GHz.
%}

clear, clc, clf
Sys.S = 1;
Sys.D = 1000; % MHz

Sys.Pop = [1 0 1];

Sys.lwpp = 0.5;   % mT

Exp.mwFreq = 9.248;  % GHz
Exp.Range = [280 380];      % mT
Exp.Harmonic = 0;

pepper(Sys,Exp);
