%% EasySpin Academy 2020 - Session 7 - Least-squares fitting 1
%===============================================================================
% (based on version 6.0.0-dev.26, possible changes for 6.0.0 final release)


%>> Welcome to day 2
%>> Review website, zip file, Slido
%>> Happy Hour: for asking questions!

%{
This session demonstrates the interactive use of EasySpin's least-squares
fitting function, esfit().
%}

%% DEMONSTRATION 07-01: Fitting simple spectrum, esfit interface

% Clear, and load data
clear, clc, clf

[B,spc] = eprload('FeS_1.DTA');
plot(B,spc);

% Set up experiment
Exp.mwFreq = 9.5;
Exp.Range = [min(B) max(B)]; % mT
Exp.nPoints = numel(spc);

% Set up spin system with starting parameters
Sys0.g = [1.9 2.0 2.1];
Sys0.gStrain = [1 1 1]*0.03;

% Set up Vary structure with all parameters that can be varied
SysVary.g = [1 1 1]*0.05;
SysVary.gStrain = [1 1 1]*0.03;

% Function handles: needed for esfit()
f = @sin
f(0.5)
g = @(x)x^2
g(5)

% Call esfit
esfit(@pepper,spc,Sys0,SysVary,Exp);
% (CALLING SYNTAX WILL CHANGE FOR FINAL 6.0 RELEASE)

% Demonstrate and explain
% - function
% - parameter table, incl. editing lower/upper bounds
% - method
% - target
% - scaling
% - start point
% - RMSD display
% - saved parameter sets

%% EXERCISE 07-01: Fitting simple spectrum
%{
Load FeS_2.DTA (mwFreq=9.5 GHz). This is a system similar to the one in the
demonstration. Use esfit to determine the g tensor and the g strain. Explore:
(a) different fitting methods, (b) different fitting targets, (c) different
scaling method, (d) different starting points.
Find the best-fit parameter set. Save or write down your parameter set.
%}

% Clear, and load data
clear, clc, clf
[B,spc] = eprload('FeS_2.DTA');
plot(B,spc);

% Set up experiment
Exp.mwFreq = 9.5;
Exp.Range = [min(B) max(B)]; % mT

% Set up spin system with starting parameters
Sys0.g = [1.9 2.0 2.1];
Sys0.gStrain = [1 1 1]*0.03;

% Set up Vary structure with all parameters that can be varies
SysVary.g = [1 1 1]*0.05;
SysVary.gStrain = [1 1 1]*0.03;

% Call esfit
esfit(@pepper,spc,Sys0,SysVary,Exp);
% (CALLING SYNTAX WILL CHANGE FOR FINAL 6.0 RELEASE)


%% DEMONSTRATION 07-02: Plotting after interactive fitting

% There are two ways:
% (1) Using the simulated spectrum provided by "export" from the GUI

% Click "export", look for fit structure (fit1, etc) in workspace
figure
plot(fit1.expSpec);
hold on
plot(fit1.fitSpec);

% (2) Using the fitted parameters, and re-simulate the spectrum
% Load data
clc, clf
[Bexp,spcexp] = eprload('FeS_1.DTA');

% Set up experiment
Exp.mwFreq = 9.5; % make sure it's the same as in the experiment
Exp.Range = [min(Bexp) max(Bexp)]; % mT

% Set up spin system with fitted parameters
% (either use fit structure from export, or type values)
%FeS.g = [1.888 1.972 2.113];
%FeS.gStrain = [0.042 0.045 0.022];
FeS = fit1.Sys;

[Bsim,spcsim] = pepper(FeS,Exp);

% Plotting now shows that the sim and exp spectra are scaled differently
plot(Bexp,spcexp,Bsim,spcsim)

% Important step: rescaling! Use same method as in the esfit GUI
% (it's also exported in the fit structure)
spcsim = rescale(spcsim,spcexp,'lsq0');

plot(Bexp,spcexp,Bsim,spcsim)

%% EXERCISE 07-02: Plotting after interactive fitting
%{
Take the best-fit parameters from your fitting procedure in Exercise 07-01
and use them to simulate the spectrum. Plot the experimental and the
(rescaled) simulated spectrum on top of each other.
%}

% same as demonstration 07-02, but with
FeS.g = [1.918 2.005 2.070];
FeS.gStrain = [0.026 0.042 0.030];

%% DEMONSTRATION 07-03: Fitting highly structured spectra

% Shows that fitting is not automatic, but requires a lot of trials, or --
% better -- good initial values from literature or from an analysis of
% line spacings.

clear, clc, clf
[B,spc] = eprload('radical.DTA');
plot(B,spc)

Exp.mwFreq = 9.5; % make sure it's the same as in the experiment
Exp.Range = [min(B) max(B)]; % mT

Sys0.Nucs = '1H,1H';
Sys0.n = [5 3];

Sys0.g = 2;
Sys0.A = [20 8]; % MHz
Sys0.lwpp = [0 0.03]; % mT

SysVary.g = 0.005;
SysVary.A = [4 4]; % MHz
SysVary.lwpp = [0 0.02]; % mT

esfit(@garlic,spc,Sys0,SysVary,Exp);
% (CALLING SYNTAX WILL CHANGE FOR FINAL 6.0 RELEASE)

% vary fitting target
% notice how difficult it is!
% 4D error function surface has many minima, like an egg carton

% Local vs global minimum example: lowest points on earth
% - Global: Dead Sea, Israel/Jordan
% - Local: Death Valley, California; Caspian Depression, Kazakhstan

%% EXERCISE 07-03: Fitting highly structured spectra
%{
Try to find a good fit for the spectrum from the simulation, using esfit
interactively.
%}

% Actual values (approximately):
% Sys.A = [16.654 9.8016]; % MHz
% Sys.g = 2.00153;
% Sys.lwpp = [0 0.0368];
