%% EasySpin Academy 2020 - Session 8 - Least-squares fitting 2
%===============================================================================
% (based on version 6.0.0-dev.26, possible changes for 6.0.0 final release)
%{
This session demonstrates additional features of esfit(): multi-component
spectra, command-line calls
%}

%% DEMONSTRATION 08-01: Multi-component spectra; options

% To fit mixtures, supply cell arrays for Sys and Vary to esfit()

% Example: mixture of two nitroxide spectra
clear, clc, clf
[B,spc] = eprload('nx2.DTA');
plot(B,spc);

% Experimental parameters
Exp.mwFreq = 9.5; % from par.MWFQ
Exp.Range = [min(B),max(B)];

% Define nitroxide parameters
Nx.g = [2.0085 2.0065 2.003];
Nx.Nucs = '14N';
Nx.A = [20 20 95]; % MHz
Nx.lwpp = 0.2;

% Define two nitroxides differing in tcorr and weight
Nx1 = Nx;
Nx2 = Nx;
Nx1.logtcorr = -9;
Nx2.logtcorr = -8;
Nx1.weight = 0.5;
Nx2.weight = 1-Nx1.weight;

% Fit tcorr, weight, and A(3)
Vary1.weight = 0.5;
Vary2.weight = 0.5;
Vary1.logtcorr = 0.5;
Vary2.logtcorr = 0.5;
Vary1.A(3) = 10;
Vary2.A(3) = 10;

esfit(@chili,spc,{Nx1,Nx2},{Vary1,Vary2},Exp);
% (CALLING SYNTAX WILL CHANGE FOR FINAL 6.0 RELEASE)

%% EXERCISE 08-01: Multi-component spectra
%{
Take the nitroxide spectral mixture from the previous demonstration and
pretend you additionally don't know lwpp and g(1). Fit them, together
with weight, tcorr, and A(3) using esfit.
%}
%{
% Actual values:
Nx1.A(3) = 100;
Nx1.logtcorr = -9.3094;
Nx1.weight = 0.089045;
Nx2.A(3) = 100;
Nx2.logtcorr = -8.1857;
Nx2.weight = 0.91095
%}

%% DEMONSTRATION 08-02: Command line call of esfit

% Reminder: use "Save parameter set" and "export" to get fit result out of
% esfit GUI to MATLAB workspace

% Alternative: command-line call of esfit

clear, clc, clf
% Load nitroxide spectrum
[B,spc,par] = eprload('nx1.DTA');

% show par: MWFQ
Exp.mwFreq = par.MWFQ/1e9;
Exp.Range = [min(B),max(B)];

% Define spin system values
Nx.g = [2.0085 2.0065 2.003];
Nx.Nucs = '14N';
Nx.A = [20 20 100]; % MHz
Nx.lwpp = 0.2;

% For fitting tcorr, it's better to use logtcorr instead of tcorr
Nx.logtcorr = -9;

Vary.A = [0 0 20];
Vary.logtcorr = 1;

% Interactive form:
esfit(@chili,spc,Nx,Vary,Exp);
% (CALLING SYNTAX WILL CHANGE FOR FINAL 6.0 RELEASE)

% Non-interactive form:
[fitSys,fitSpec,residuals] = esfit(@chili,spc,Nx,Vary,Exp);
% (CALLING SYNTAX WILL CHANGE FOR FINAL 6.0 RELEASE)

subplot(2,1,1);
plot(B,spc,B,fitSpec);
subplot(2,1,2);
plot(B,residuals);

% Adding simulation and fitting options:
Opt = [];
FitOpt.Method = 'montecarlo';
[fitSys,fitSpec,residuals] = esfit(@chili,spc,Nx,Vary,Exp,Opt,FitOpt);
% (CALLING SYNTAX WILL CHANGE FOR FINAL 6.0 RELEASE)

% Algorithm and target function
FitOpt.Method = 'levmar int';
[fitSys,fitSpec,residuals] = esfit(@chili,spc,Nx,Vary,Exp,Opt,FitOpt);
% (CALLING SYNTAX WILL CHANGE FOR FINAL 6.0 RELEASE)

% Scaling
FitOpt.Scaling = 'lsq0';

% Maximum time
FitOpt.maxTime = 1;

% Show algorithm parameters in esfit() documentation
