%% EasySpin Academy 2020 - Session 17 - Varia
%===============================================================================
% (based on version 6.0.0-dev.26, possible changes for 6.0.0 final release)

%{
This session discusses topics that were suggested by the audience on day 2.
%}

%% DEMONSTRATION 17-01: Broadenings in solid samples

% Level 0: lwpp/lw
% - isotropic, field-domain, no physical model
% - lwpp Gaussian: unresolved hyperfine, isotropic
% - lwpp Lorentzian: isotropic 1/T2 broadening, exchange narrowing (e.g. pure DPPH)
clear, clc, clf
Sys.S = 1/2;
Sys.g = [2 2.4 3];
Sys.lwpp = 2;
Exp.mwFreq = 9.5;
pepper(Sys,Exp);

% Level 1: HStrain
% - anisotropic broadening "tensor"
% - frequency domain
% - Gaussian distribution of energy levels, without specifying origin
% - at the level of total Hamiltonian, not individual terms
Sys.lwpp = [0 0];
Sys.HStrain = 5*30;
pepper(Sys,Exp);
% -> broadening are field dependent due to different g values

% Level 2: gStrain, AStrain, DStrain
% - Gaussian distributions of spin Hamiltonian parameters
% - one width for every principal value
% - broadening tensors are collinear with their tensors
% - g/A/DStrain: distribution of geometries->distribution of spin Ham parameters
Sys.lwpp = [0 0];
Sys.HStrain = 0;
Sys.gStrain = [0.03 0.1 0.2];
pepper(Sys,Exp);

% Example for DStrain: Gd(III)
clear, clc
Sys.S = 7/2;
Sys.D = 1000;
Sys.lwpp = 5;
Exp.mwFreq = 95;
Exp.Range = [3100 3800];
[B,spc0] = pepper(Sys,Exp);
plot(B,spc0);

% Show separate transitions
Opt.Output = 'separate';
Exp.Harmonic = 0;
pepper(Sys,Exp,Opt);

% Run without separate transitions again

% Now use DStrain for comparison
Sys.DStrain = 150;
[B,spc1] = pepper(Sys,Exp);

% Plot the comparison: outer transitions are broadened more than central
plot(B,spc0,B,spc1);

%% DEMONSTRATION 17-02: Coupled spins

% Effect of dipolar coupling

clear, clc

Sys.g = [2; 2.1];
Sys.S = [1/2 1/2];
Sys.dip = 400;
Sys.lwpp = 20; % MHz

Exp.Field = 1100;

nu = mt2mhz(Exp.Field,Sys.g)/1e3;
[B,spc] = pepper(Sys,Exp);
plot(B,spc);
xline(nu(1),'r');
xline(nu(2),'r');

% Increase Sys.dip to 400, observe appearance of forb. transitions
% Restrict freq range
Exp.mwRange = [29 35];
[B,spc] = pepper(Sys,Exp);
plot(B,spc);

% Simulate a second spectrum, same dip coupling, g1=g2
Sys.g = [2.05 2.05];
[B,spc1] = pepper(Sys,Exp);
plot(B,spc,B,spc1);

% Notice possible artifact at center -> increase Opt.nKnots to see if it
% is "real":
Opt.nKnots = 300;
[B,spc1] = pepper(Sys,Exp,Opt);
plot(B,spc,B,spc1);

% Observation from comparison:
% Different dipolar splittings despite identical dipolar coupling tensor
% dip >> g1-g2 -> strong coupling regime, splitting=1.5*coupling
% dip << g1-g2 -> weak coupling regime, splitting=coupling

% Splitting vs coupling!
% - splitting is observed in the spectrum
% - coupling is the strength of the interaction in the Hamiltonian
% Also applies to hyperfine
