%% EasySpin Academy 2020 - Session 18 - Varia
%===============================================================================
% (based on version 6.0.0-dev.26, possible changes for 6.0.0 final release)

%{
This session discusses topics that were suggested by the audience on day 2.
%}

%% DEMONSTRATION 18-01: Higher-order operators
% Tb(4+) system
clear, clc, clf
Tb.S = 7/2;
Tb.g = 2.0136;

b = -2527.53/60;
B40 = b; B44 = 5*b;
c = -24.84/1260;
B60 = c; B64 = -21*c;
Tb.B4 =     [B44 0 0 0 B40 0 0 0 0];
Tb.B6 = [0 0 B64 0 0 0 B60 0 0 0 0 0 0];

% Compute the energy level diagram using EasySpin's levelsplot() function
levelsplot(Tb,'z',[0 2500])

% Show documentation on high-order operators

% Discuss anticrossing
B0 = linspace(0,2500,10001);
E = levels(Tb,[0,0]*pi/180,B0);
plot(B0,E);

% Increase second angle (theta) by 1 degree at a time, observe
% anticrossings

% Show terbium animation example from examples/varia folder

%% DEMONSTRATION 18-02: Trajectory-based simulation (cardamom)

% cardamom() can simulate motional EPR spectra from trajectories,
% either stochastic trajectories or MD trajectories

% Use stochtraj_diffusion to generate stochastic rotational diffusion
% trajectory
clear, clc
Sys.tcorr = 15e-9;  % rotational correlation time, s
[t,Rtraj] = stochtraj_diffusion(Sys);

% Look at size of Rtraj
Rzz = squeeze(Rtraj(3,3,:));

% Plot the time dependence of an element of the rotation matrix
plot(t/1e-6,Rzz)
xlabel('time (µs)');
ylabel('R_{zz}');

% Use mdload() to load MD trajectories.
%   Works with CHARMM and NAMD.
%   Show documentation of mdload()

%% DEMONSTRATION 18-03: Trajectory-based simulation
clear, clf

% Spin system
Sys.Nucs = '14N';
Sys.g = [2.009, 2.006, 2.002];
Sys.A = mt2mhz([6, 36]/10); % MHz
Sys.tcorr = 15e-9;  % rotational correlation time, s
Sys.lw = [0.0, 0.1]; % mT

% Experiment
Exp.mwFreq = 9.4;

% Parameters for cardamom
Par.Model = 'diffusion';
Par.nTraj = 200;
Par.dtSpin = 1e-9;
Par.dtSpatial = 1e-9;
Par.nSteps = 230;

Opt.Verbosity = 1;

% Simulate spectrum using cardamom (trajectory propagation)
[Bcard,spc] = cardamom(Sys,Exp,Par,Opt);
ycard = spc/max(spc);
  
% Simulate spectrum using chili (stochastic Liouville equation)
[Bchili,spc] = chili(Sys, Exp);
ychili = spc/max(spc);

% Plot for comparison
plot(Bchili,ychili,'k',Bcard,ycard,'r');
axis tight
set(gca,'ytick',[]);
xlabel('magnetic field (mT)')
legend('chili','cardamom')
legend('boxoff')
box on


%% DEMONSTRATION 18-04: EasySpin behind the scenes; the future

% Show tests, run them

% Show github repo

% Mention contributors

% Future: expected features for EasySpin 6.0 final
% - rework of frames interface
% - revamp of esfit()
